==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/ga.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Tá an t-ainm a thugtar rófhada",
    "The given web address is too long" : "Tá an seoladh gréasáin a thugtar rófhada",
    "The given web address is not a valid URL" : "Níl an seoladh gréasáin a thugtar mar URL bailí",
    "The given legal notice address is too long" : "Tá an seoladh fógra dlí a thugtar rófhada",
    "The given legal notice address is not a valid URL" : "Ní URL bailí an seoladh fógra dlíthiúil a tugadh",
    "The given privacy policy address is too long" : "Tá an seoladh polasaí príobháideachta a thugtar ró-fhada",
    "The given privacy policy address is not a valid URL" : "Ní URL bailí an seoladh polasaí príobháideachta a tugadh",
    "The given slogan is too long" : "Tá an mana a thugtar ró-fhada",
    "The given color is invalid" : "Tá an dath a thugtar neamhbhailí",
    "Disable-user-theming should be true or false" : "Díchumasaigh-úsáideoir-téamaí ba chóir a bheith fíor nó bréagach",
    "Saved" : "Shábháil",
    "Invalid app given" : "Aip neamhbhailí tugtha",
    "Invalid type for setting \"defaultApp\" given" : "Cineál neamhbhailí don socrú \"defaultApp\" tugtha",
    "Invalid setting key" : "Eochair shocruithe neamhbhailí",
    "The file was uploaded" : "Uaslódáladh an comhad",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Sáraíonn an comhad uaslódáilte an treoir upload_max_filesize i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Sáraíonn an comhad uaslódáilte an treoir MAX_FILE_SIZE a sonraíodh san fhoirm HTML",
    "The file was only partially uploaded" : "Níor uaslódáladh an comhad ach go páirteach",
    "No file was uploaded" : "Níor uaslódáladh aon chomhad",
    "Missing a temporary folder" : "Fillteán sealadach ar iarraidh",
    "Could not write file to disk" : "Níorbh fhéidir an comhad a scríobh ar an diosca",
    "A PHP extension stopped the file upload" : "Chuir síneadh PHP stop le huaslódáil an chomhaid",
    "No file uploaded" : "Níor uaslódáladh aon chomhad",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Tá téama saincheaptha in úsáid agat cheana féin. Seans go mbeidh socruithe feidhmchláir téamaí forscríofa leis sin.",
    "Theming" : "Téamaí",
    "Appearance and accessibility" : "Cuma agus inrochtaineacht",
    "PHP Imagick module" : "Modúl PHP Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Níl an modúl PHP \"imagick\" cumasaithe cé go bhfuil an app téamaí. Chun go n-oibreoidh giniúint favicon i gceart, ní mór duit an modúl seo a shuiteáil agus a chumasú.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Níl aon tacaíocht SVG ag an modúl PHP \"imagick\" sa chás seo. Le haghaidh comhoiriúnacht níos fearr moltar é a shuiteáil.",
    "Dark theme with high contrast mode" : "Téama dorcha le modh ardchodarsnachta",
    "Enable dark high contrast mode" : "Cumasaigh mód dorcha ardchodarsnachta",
    "Similar to the high contrast mode, but with dark colours." : "Cosúil leis an modh ardchodarsnachta, ach le dathanna dorcha.",
    "Dark theme" : "Téama dorcha",
    "Enable dark theme" : "Cumasaigh téama dorcha",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Téama dorcha chun do shúile a mhaolú tríd an luminosity agus gile iomlán a laghdú.",
    "System default theme" : "Téama réamhshocraithe an chórais",
    "Enable the system default" : "Cumasaigh réamhshocrú an chórais",
    "Using the default system appearance." : "Ag baint úsáide as cuma an chórais réamhshocraithe.",
    "Dyslexia font" : "cló disléicse",
    "Enable dyslexia font" : "Cumasaigh cló disléicse",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Is cló saor in aisce OpenDyslexic é a cruthaíodh chun cuid de na botúin léitheoireachta coitianta a chóireáil a bhaineann le disléicse.",
    "High contrast mode" : "Modh ardchodarsnachta",
    "Enable high contrast mode" : "Cumasaigh modh ardchodarsnachta",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Modh ardchodarsnachta chun do sheoltóireacht a shaoradh. Beidh caighdeán radharcach laghdaithe ach ardófar an soiléireacht.",
    "Light theme" : "Téama éadrom",
    "Enable the default light theme" : "Cumasaigh an téama réamhshocraithe solais",
    "The default light appearance." : "An chuma éadrom réamhshocraithe.",
    "Legal notice" : "Fógra dlíthiúil",
    "Privacy policy" : "Beartas Príobháideachais",
    "Adjust the Nextcloud theme" : "Coigeartaigh an téama Nextcloud",
    "Name" : "Ainm",
    "Web link" : "Nasc gréasáin",
    "a safe home for all your data" : "baile sábháilte do do shonraí go léir",
    "Slogan" : "mana",
    "Primary color" : "Dath bunscoile",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Úsáidtear an dath príomhúil chun gnéithe cosúil le cnaipí tábhachtacha a aibhsiú. D'fhéadfadh sé go ndéanfaí é a choigeartú beagán ag brath ar an scéimre datha reatha.",
    "Legal notice link" : "Nasc fógra dlíthiúil",
    "Privacy policy link" : "Nasc polasaí príobháideachta",
    "Header logo" : "Lógó ceanntásca",
    "Upload new header logo" : "Íoslódáil an ceanntásc lógó nua",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Íosluchtaigh favicon nua",
    "User settings" : "Socruithe úsáideora",
    "Disable user theming" : "Díchumasaigh téamaí úsáideora",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Cé gur féidir leat do chás a roghnú agus a shaincheapadh, is féidir le húsáideoirí a gcúlra agus a ndathanna a athrú. Más mian leat do shaincheapadh a fhorfheidhmiú, is féidir leat é seo a scoránaigh.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Is féidir cuma agus mothú do chás agus do chliaint a dtacaítear leo a shaincheapadh go héasca le téamaí. Beidh sé seo le feiceáil do gach úsáideoir.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "In ionad íomhá chúlra is féidir leat dath cúlra simplí a chumrú freisin. Má úsáideann tú íomhá cúlra beidh tionchar ag athrú an datha seo ar dhath deilbhíní roghchláir na haipe.",
    "Background color" : "Dath an chúlra",
    "Upload new logo" : "Íosluchtaigh lógó nua",
    "Logo" : "Lógó",
    "Upload new background and login image" : "Íosluchtaigh cúlra nua agus logáil isteach",
    "Background and login image" : "Cúlra agus íomhá logáil isteach",
    "Advanced options" : "Ardroghanna",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Suiteáil an síneadh ImageMagick PHP le tacaíocht d'íomhánna SVG chun favicons a ghiniúint go huathoibríoch bunaithe ar an lógó agus an dath uaslódáilte.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Tá rochtain uilíoch an-tábhachtach dúinne. Leanaimid caighdeáin ghréasáin agus seiceálann muid chun gach rud a dhéanamh inúsáidte freisin gan luch, agus bogearraí cúnta cosúil le léitheoirí scáileáin. Tá sé mar aidhm againn cloí leis na {linkstart}Treoirlínte um Inrochtaineacht Ábhar Gréasáin{linkend} 2.1 ar leibhéal AA, leis an téama ardchodarsnachta fiú ar leibhéal AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Má fhaigheann tú aon fhadhb, ná bíodh drogall ort iad a thuairisciú ar {issuetracker}ár lorgaire saincheisteanna{linkend}. Agus más mian leat a bheith páirteach, tar isteach i {designteam}ár bhfoireann deartha{linkend}!",
    "Unable to apply the setting." : "Ní féidir an socrú a chur i bhfeidhm.",
    "Appearance and accessibility settings" : "Cuma agus socruithe inrochtaineachta",
    "Misc accessibility options" : "Roghanna inrochtaineachta éagsúla",
    "Enable blur background filter (may increase GPU load)" : "Cumasaigh an scagaire cúlra doiléir (d'fhéadfadh sé ualach GPU a mhéadú)",
    "Customization has been disabled by your administrator" : "Dhíchumasaigh do riarthóir an oiriúnú",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Socraigh dath príomhúil chun aird a tharraingt ar ghnéithe tábhachtacha. D’fhéadfadh difríocht bheag a bheith idir an dath a úsáidtear le haghaidh eilimintí mar chnaipí príomhúla de réir mar a choigeartaítear é chun riachtanais inrochtaineachta a chomhlíonadh.",
    "Background and color" : "Cúlra agus dath",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Is féidir an cúlra a shocrú d'íomhá ón tacar réamhshocraithe, íomhá saincheaptha uaslódáilte, nó dath simplí.",
    "Keyboard shortcuts" : "Aicearraí méarchláir",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "I gcásanna áirithe is féidir le aicearraí méarchláir cur isteach ar uirlisí inrochtaineachta. Chun gur féidir díriú ar d’uirlis i gceart is féidir leat gach aicearra méarchláir a dhíchumasú anseo. Díchumasóidh sé seo gach aicearra atá ar fáil in aipeanna freisin.",
    "Disable all keyboard shortcuts" : "Díchumasaigh gach aicearra méarchláir",
    "Current selected app: {app}, position {position} of {total}" : "Aip roghnaithe reatha: {app}, suíomh {position} de {total}",
    "Move up" : "Éirí suas",
    "Move down" : "Bog síos",
    "Select a background from your files" : "Roghnaigh cúlra ó do chuid comhad",
    "Select background" : "Roghnaigh cúlra",
    "No background has been selected" : "Níor roghnaíodh aon chúlra",
    "Custom background" : "Cúlra saincheaptha",
    "Plain background" : "Cúlra simplí",
    "Default background" : "Cúlra réamhshocraithe",
    "Theme selection is enforced" : "Cuirtear an rogha téamaí i bhfeidhm",
    "Could not set the app order" : "Níorbh fhéidir an t-ordú aipe a shocrú",
    "Could not reset the app order" : "Níorbh fhéidir an t-ordú aipe a athshocrú",
    "Navigation bar settings" : "Socruithe barra nascleanúna",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Is féidir leat an t-ordú app a úsáidtear don bharra nascleanúna a chumrú. Is é an chéad iontráil an aip réamhshocraithe, a osclaítear tar éis logáil isteach nó nuair a chliceáiltear ar an lógó.",
    "The default app can not be changed because it was configured by the administrator." : "Ní féidir an app réamhshocraithe a athrú toisc go raibh sé cumraithe ag an riarthóir.",
    "The app order was changed, to see it in action you have to reload the page." : "Athraíodh an t-ordú aip, chun é a fheiceáil i ngníomh caithfidh tú an leathanach a athlódáil.",
    "Reset default app order" : "Athshocraigh ordú app réamhshocraithe",
    "Could not set primary color" : "Níorbh fhéidir an príomhdath a shocrú",
    "Reset primary color" : "Athshocraigh dath príomhúil",
    "Could not set global default apps" : "Níorbh fhéidir aipeanna réamhshocraithe domhanda a shocrú",
    "Default app" : "Aip réamhshocraithe",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Is é an app réamhshocraithe an app atá e.g. a osclaítear tar éis logáil isteach nó nuair a chliceáiltear an lógó sa roghchlár.",
    "Use custom default app" : "Bain úsáid as aip réamhshocraithe saincheaptha",
    "Global default app" : "Aip réamhshocraithe domhanda",
    "Global default apps" : "Aipeanna réamhshocraithe domhanda",
    "Default app priority" : "Tosaíocht réamhshocraithe aipe",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Mura bhfuil aip cumasaithe d’úsáideoir, úsáidtear an chéad aip eile le tosaíocht níos ísle.",
    "Select a custom color" : "Roghnaigh dath saincheaptha",
    "Reset to default" : "Athshocraigh go réamhshocrú",
    "Upload" : "Uaslódáil",
    "Remove background image" : "Bain íomhá cúlra",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Is tábhachtach go mór dúinn rochtain uilepháirtíoch a chur ar fáil. Leanaimid na caighdeáin ghréasáin agus déanaimid seiceáil chun gach rud a úsáid a dhéanamh gan luchóg, agus bogearraí chabhrach cosúil le léitheoirí scáileáin. Táimid ag tógáil leis an gcomhlíonadh {guidelines}Treoracha Rochtanaíochta Ábhar Gréasáin{linkend} 2.1 ar leibhéal AA, leis an téama ardshaincheaptha fiú ar leibhéal AAA.",
    ". Unable to apply the setting." : ". Ní féidir an socrú a chur i bhfeidhm."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/ga.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Tá an t-ainm a thugtar rófhada",
    "The given web address is too long" : "Tá an seoladh gréasáin a thugtar rófhada",
    "The given web address is not a valid URL" : "Níl an seoladh gréasáin a thugtar mar URL bailí",
    "The given legal notice address is too long" : "Tá an seoladh fógra dlí a thugtar rófhada",
    "The given legal notice address is not a valid URL" : "Ní URL bailí an seoladh fógra dlíthiúil a tugadh",
    "The given privacy policy address is too long" : "Tá an seoladh polasaí príobháideachta a thugtar ró-fhada",
    "The given privacy policy address is not a valid URL" : "Ní URL bailí an seoladh polasaí príobháideachta a tugadh",
    "The given slogan is too long" : "Tá an mana a thugtar ró-fhada",
    "The given color is invalid" : "Tá an dath a thugtar neamhbhailí",
    "%1$s should be true or false" : "Ba chóir go mbeadh %1$s fíor nó bréagach",
    "%1$s can only be set to %2$s through the API" : "Ní féidir %1$s a shocrú go %2$s ach tríd an API",
    "Invalid setting key" : "Eochair shocruithe neamhbhailí",
    "Saved" : "Shábháil",
    "Invalid app given" : "Aip neamhbhailí tugtha",
    "Invalid type for setting \"defaultApp\" given" : "Cineál neamhbhailí don socrú \"defaultApp\" tugtha",
    "The file was uploaded" : "Uaslódáladh an comhad",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Sáraíonn an comhad uaslódáilte an treoir upload_max_filesize i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Sáraíonn an comhad uaslódáilte an treoir MAX_FILE_SIZE a sonraíodh san fhoirm HTML",
    "The file was only partially uploaded" : "Níor uaslódáladh an comhad ach go páirteach",
    "No file was uploaded" : "Níor uaslódáladh aon chomhad",
    "Missing a temporary folder" : "Fillteán sealadach ar iarraidh",
    "Could not write file to disk" : "Níorbh fhéidir an comhad a scríobh ar an diosca",
    "A PHP extension stopped the file upload" : "Chuir síneadh PHP stop le huaslódáil an chomhaid",
    "No file uploaded" : "Níor uaslódáladh aon chomhad",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Tá téama saincheaptha in úsáid agat cheana féin. Seans go mbeidh socruithe feidhmchláir téamaí forscríofa leis sin.",
    "Theming" : "Téamaí",
    "Appearance and accessibility" : "Cuma agus inrochtaineacht",
    "PHP Imagick module" : "Modúl PHP Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Níl an modúl PHP \"imagick\" cumasaithe cé go bhfuil an app téamaí. Chun go n-oibreoidh giniúint favicon i gceart, ní mór duit an modúl seo a shuiteáil agus a chumasú.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Níl aon tacaíocht SVG ag an modúl PHP \"imagick\" sa chás seo. Le haghaidh comhoiriúnacht níos fearr moltar é a shuiteáil.",
    "Dark theme with high contrast mode" : "Téama dorcha le modh ardchodarsnachta",
    "Enable dark high contrast mode" : "Cumasaigh mód dorcha ardchodarsnachta",
    "Similar to the high contrast mode, but with dark colours." : "Cosúil leis an modh ardchodarsnachta, ach le dathanna dorcha.",
    "Dark theme" : "Téama dorcha",
    "Enable dark theme" : "Cumasaigh téama dorcha",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Téama dorcha chun do shúile a mhaolú tríd an luminosity agus gile iomlán a laghdú.",
    "System default theme" : "Téama réamhshocraithe an chórais",
    "Enable the system default" : "Cumasaigh réamhshocrú an chórais",
    "Using the default system appearance." : "Ag baint úsáide as cuma an chórais réamhshocraithe.",
    "Dyslexia font" : "cló disléicse",
    "Enable dyslexia font" : "Cumasaigh cló disléicse",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Is cló saor in aisce OpenDyslexic é a cruthaíodh chun cuid de na botúin léitheoireachta coitianta a chóireáil a bhaineann le disléicse.",
    "High contrast mode" : "Modh ardchodarsnachta",
    "Enable high contrast mode" : "Cumasaigh modh ardchodarsnachta",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Modh ardchodarsnachta chun do sheoltóireacht a shaoradh. Beidh caighdeán radharcach laghdaithe ach ardófar an soiléireacht.",
    "Light theme" : "Téama éadrom",
    "Enable the default light theme" : "Cumasaigh an téama réamhshocraithe solais",
    "The default light appearance." : "An chuma éadrom réamhshocraithe.",
    "Legal notice" : "Fógra dlíthiúil",
    "Privacy policy" : "Beartas Príobháideachais",
    "Adjust the Nextcloud theme" : "Coigeartaigh an téama Nextcloud",
    "Could not set global default apps" : "Níorbh fhéidir aipeanna réamhshocraithe domhanda a shocrú",
    "Navigation bar settings" : "Socruithe barra nascleanúna",
    "Default app" : "Aip réamhshocraithe",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Is é an app réamhshocraithe an app atá e.g. a osclaítear tar éis logáil isteach nó nuair a chliceáiltear an lógó sa roghchlár.",
    "Use custom default app" : "Bain úsáid as aip réamhshocraithe saincheaptha",
    "Global default app" : "Aip réamhshocraithe domhanda",
    "Global default apps" : "Aipeanna réamhshocraithe domhanda",
    "Default app priority" : "Tosaíocht réamhshocraithe aipe",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Mura bhfuil aip cumasaithe d’úsáideoir, úsáidtear an chéad aip eile le tosaíocht níos ísle.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Is féidir cuma agus mothú do chás agus do chliaint a dtacaítear leo a shaincheapadh go héasca le téamaí. Beidh sé seo le feiceáil do gach úsáideoir.",
    "Name" : "Ainm",
    "Web link" : "Nasc gréasáin",
    "Slogan" : "mana",
    "a safe home for all your data" : "baile sábháilte do do shonraí go léir",
    "Legal notice link" : "Nasc fógra dlíthiúil",
    "Privacy policy link" : "Nasc polasaí príobháideachta",
    "Background and color" : "Cúlra agus dath",
    "Primary color" : "Dath bunscoile",
    "Set the default primary color, used to highlight important elements." : "Socraigh an príomh-dath réamhshocraithe, a úsáidtear chun eilimintí tábhachtacha a aibhsiú.",
    "The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "D’fhéadfadh an dath a úsáidtear le haghaidh eilimintí amhail príomhchnaipí a bheith beagán difriúil de réir mar a dhéantar é a choigeartú chun riachtanais inrochtaineachta a chomhlíonadh.",
    "Background color" : "Dath an chúlra",
    "When no background image is set the background color will be used." : "Nuair nach mbíonn aon íomhá chúlra socraithe, úsáidfear dath an chúlra.",
    "Otherwise the background color is by default generated from the background image, but can be adjusted to fine tune the color of the navigation icons." : "Seachas sin, gintear an dath cúlra de réir réamhshocraithe ón íomhá chúlra, ach is féidir é a choigeartú chun dath na ndeilbhíní nascleanúna a choigeartú go mín.",
    "Use a plain background color instead of a background image." : "Bain úsáid as dath cúlra simplí in ionad íomhá chúlra.",
    "Remove background image" : "Bain íomhá cúlra",
    "Background image" : "Íomhá cúlra",
    "Favicon" : "Favicon",
    "Logo" : "Lógó",
    "Navigation bar logo" : "Lógó an bharra nascleanúna",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Cé gur féidir leat do chás a roghnú agus a shaincheapadh, is féidir le húsáideoirí a gcúlra agus a ndathanna a athrú. Más mian leat do shaincheapadh a fhorfheidhmiú, is féidir leat é seo a scoránaigh.",
    "Disable user theming" : "Díchumasaigh téamaí úsáideora",
    "Current selected app: {app}, position {position} of {total}" : "Aip roghnaithe reatha: {app}, suíomh {position} de {total}",
    "Navigation bar app order" : "Ordú aip barra nascleanúna",
    "Move up" : "Éirí suas",
    "Move down" : "Bog síos",
    "Theme selection is enforced" : "Cuirtear an rogha téamaí i bhfeidhm",
    "Could not set the app order" : "Níorbh fhéidir an t-ordú aipe a shocrú",
    "Could not reset the app order" : "Níorbh fhéidir an t-ordú aipe a athshocrú",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Is féidir leat an t-ordú app a úsáidtear don bharra nascleanúna a chumrú. Is é an chéad iontráil an aip réamhshocraithe, a osclaítear tar éis logáil isteach nó nuair a chliceáiltear ar an lógó.",
    "The default app can not be changed because it was configured by the administrator." : "Ní féidir an app réamhshocraithe a athrú toisc go raibh sé cumraithe ag an riarthóir.",
    "The app order was changed, to see it in action you have to reload the page." : "Athraíodh an t-ordú aip, chun é a fheiceáil i ngníomh caithfidh tú an leathanach a athlódáil.",
    "Reset default app order" : "Athshocraigh ordú app réamhshocraithe",
    "Select a background from your files" : "Roghnaigh cúlra ó do chuid comhad",
    "Select background" : "Roghnaigh cúlra",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Is féidir an cúlra a shocrú d'íomhá ón tacar réamhshocraithe, íomhá saincheaptha uaslódáilte, nó dath simplí.",
    "Custom background" : "Cúlra saincheaptha",
    "Plain background" : "Cúlra simplí",
    "Default background" : "Cúlra réamhshocraithe",
    "Default shipped background images" : "Íomhánna cúlra réamhshocraithe seolta",
    "Keyboard shortcuts" : "Aicearraí méarchláir",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "I gcásanna áirithe is féidir le aicearraí méarchláir cur isteach ar uirlisí inrochtaineachta. Chun gur féidir díriú ar d’uirlis i gceart is féidir leat gach aicearra méarchláir a dhíchumasú anseo. Díchumasóidh sé seo gach aicearra atá ar fáil in aipeanna freisin.",
    "Disable all keyboard shortcuts" : "Díchumasaigh gach aicearra méarchláir",
    "Could not set primary color" : "Níorbh fhéidir an príomhdath a shocrú",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Socraigh dath príomhúil chun aird a tharraingt ar ghnéithe tábhachtacha. D’fhéadfadh difríocht bheag a bheith idir an dath a úsáidtear le haghaidh eilimintí mar chnaipí príomhúla de réir mar a choigeartaítear é chun riachtanais inrochtaineachta a chomhlíonadh.",
    "Reset primary color" : "Athshocraigh dath príomhúil",
    "Reset to default" : "Athshocraigh go réamhshocrú",
    "Non image file selected" : "Comhad nach íomhá roghnaithe",
    "Failed to upload image" : "Theip ar an íomhá a uaslódáil",
    "Preview of the selected image" : "Réamhamharc ar an íomhá roghnaithe",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Tá rochtain uilíoch an-tábhachtach dúinne. Leanaimid caighdeáin ghréasáin agus seiceálann muid chun gach rud a dhéanamh inúsáidte freisin gan luch, agus bogearraí cúnta cosúil le léitheoirí scáileáin. Tá sé mar aidhm againn cloí leis na {linkstart}Treoirlínte um Inrochtaineacht Ábhar Gréasáin{linkend} 2.1 ar leibhéal AA, leis an téama ardchodarsnachta fiú ar leibhéal AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Má fhaigheann tú aon fhadhb, ná bíodh drogall ort iad a thuairisciú ar {issuetracker}ár lorgaire saincheisteanna{linkend}. Agus más mian leat a bheith páirteach, tar isteach i {designteam}ár bhfoireann deartha{linkend}!",
    "Unable to apply the setting." : "Ní féidir an socrú a chur i bhfeidhm.",
    "Appearance and accessibility settings" : "Cuma agus socruithe inrochtaineachta",
    "Misc accessibility options" : "Roghanna inrochtaineachta éagsúla",
    "Enable blur background filter (may increase GPU load)" : "Cumasaigh an scagaire cúlra doiléir (d'fhéadfadh sé ualach GPU a mhéadú)",
    "Customization has been disabled by your administrator" : "Dhíchumasaigh do riarthóir an oiriúnú",
    "Disable-user-theming should be true or false" : "Díchumasaigh-úsáideoir-téamaí ba chóir a bheith fíor nó bréagach",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Úsáidtear an dath príomhúil chun gnéithe cosúil le cnaipí tábhachtacha a aibhsiú. D'fhéadfadh sé go ndéanfaí é a choigeartú beagán ag brath ar an scéimre datha reatha.",
    "Header logo" : "Lógó ceanntásca",
    "Upload new header logo" : "Íoslódáil an ceanntásc lógó nua",
    "Upload new favicon" : "Íosluchtaigh favicon nua",
    "User settings" : "Socruithe úsáideora",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "In ionad íomhá chúlra is féidir leat dath cúlra simplí a chumrú freisin. Má úsáideann tú íomhá cúlra beidh tionchar ag athrú an datha seo ar dhath deilbhíní roghchláir na haipe.",
    "Upload new logo" : "Íosluchtaigh lógó nua",
    "Upload new background and login image" : "Íosluchtaigh cúlra nua agus logáil isteach",
    "Background and login image" : "Cúlra agus íomhá logáil isteach",
    "Advanced options" : "Ardroghanna",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Suiteáil an síneadh ImageMagick PHP le tacaíocht d'íomhánna SVG chun favicons a ghiniúint go huathoibríoch bunaithe ar an lógó agus an dath uaslódáilte.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Is tábhachtach go mór dúinn rochtain uilepháirtíoch a chur ar fáil. Leanaimid na caighdeáin ghréasáin agus déanaimid seiceáil chun gach rud a úsáid a dhéanamh gan luchóg, agus bogearraí chabhrach cosúil le léitheoirí scáileáin. Táimid ag tógáil leis an gcomhlíonadh {guidelines}Treoracha Rochtanaíochta Ábhar Gréasáin{linkend} 2.1 ar leibhéal AA, leis an téama ardshaincheaptha fiú ar leibhéal AAA.",
    ". Unable to apply the setting." : ". Ní féidir an socrú a chur i bhfeidhm.",
    "No background has been selected" : "Níor roghnaíodh aon chúlra",
    "Select a custom color" : "Roghnaigh dath saincheaptha",
    "Upload" : "Uaslódáil"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
